@@ -621,7 +621,7 @@ static void
 pyalsahcontrolelement_dealloc(struct pyalsahcontrolelement *self)
 {
 	if (self->elem) {
-		Py_DECREF(self->callback);
+		Py_XDECREF(self->callback);
 		snd_hctl_elem_set_callback(self->elem, NULL);
 	}
 	Py_XDECREF(self->pyhandle);
@@ -1543,8 +1543,8 @@ static int element_callback(snd_hctl_elem_t *elem, unsigned int mask)
 
 	t = PyTuple_New(2);
 	if (t) {
-		if (PyTuple_SET_ITEM(t, 0, (PyObject *)pyhelem))
-			Py_INCREF(pyhelem);
+		PyTuple_SET_ITEM(t, 0, (PyObject *)pyhelem);
+		Py_INCREF(pyhelem);
 		PyTuple_SET_ITEM(t, 1, PyInt_FromLong(mask));
 		r = PyObject_CallObject(o, t);
 		Py_DECREF(t);
